﻿# -*- coding: utf-8 -*-


class SearchPanel(wx.Panel):
    """
    Class to privide a way to interactivly apply Python Regular Expressions
    to an STC in such a way that other data in the control is disturbed
    as little as possible and changes can be done and undone using
    normal STC commands.

    In addition to interactive controls, methods are supplied that can
    be used by external scripts.

    """

    FROMTOP = 0
    FORWARD = 1
    BACKWARD = 2
    WRAP = 3
    INSELECTION = 4


    def __init__(self, parent):
        """
        Default constructor. Sets up the gui componets of the panel.

        lastMatchObject:
            A place to store the match object returned from a python re
            search.

        """
        wx.Panel.__init__(self, parent, -1)

        self.lastMatchObject = None

        mainVbox = wx.BoxSizer(wx.VERTICAL)

        hbox=wx.BoxSizer(wx.HORIZONTAL)

        editBoxSizer =wx.BoxSizer(wx.VERTICAL)
        self.FindText = ed1 = SearchEditBox(self)
        self.ReplaceText = ed2 = SearchEditBox(self)
        editBoxSizer.Add(ed1,1,wx.EXPAND)
        editBoxSizer.Add(ed2,1,wx.EXPAND)

        hbox.Add(editBoxSizer,1,wx.EXPAND | wx.ALL, 5)

        rboxsizer=wx.BoxSizer(wx.VERTICAL)
        self.directionRadioBox = wx.RadioBox(self,-1,
            label='Direction',choices=['From Top','Forward','Backward','Wrap','In Selection'],
            style= wx.RA_SPECIFY_ROWS
        )
        rboxsizer.Add(self.directionRadioBox,1,wx.EXPAND | wx.ALL, 5)
        hbox.Add(rboxsizer,0,wx.EXPAND )

        buttonBoxSizer=wx.BoxSizer(wx.VERTICAL)
        for label, message in [
            ('Search', 'Search'),
            ('Replace', 'Replace'),
            ('R && S', 'ReplaceAndSearch',),
            ('Replace All','ReplaceAll'),
            ('Count', 'Count'),
            ('List', 'List')
        ]:
            buttonBoxSizer.Add(MessageButton(self, label, message),1,wx.EXPAND)

        hbox.Add(buttonBoxSizer,0,wx.EXPAND | wx.ALL, 5)
        mainVbox.Add(hbox,1,wx.EXPAND)

        self.SetSizer(mainVbox)
        mainVbox.Fit(self)


    def OnMessageButton(self, message, object):
        """
        Callback function for MessageButtons.

        Initialize some variables from the gui then call a method
        to perform the operation requested by the user.

        """
        self.direction = self.GetDirection()
        self.sFind = self.GetFindStr()
        self.sReplace = self.GetReplaceStr()
        f = getattr(self, 'On'+message, self.OnUnknownSignal)
        self.ed = MainEditor
        self.ed.SetFocus()
        return f()

    def OnUnknownSignal(self):
        pass


def test1():
    pass

if __name__=="__main__":

    def test2():
        pass

    class TestFrame(wx.Frame):

        def __init__(self):
            global MainEditor
            wx.Frame.__init__(self, None, -1, 'Ledgerbob\'s Python Search Demo')

            MainEditor = MySTC(self)
            sizer = wx.BoxSizer(wx.VERTICAL)
            sizer.Add(MainEditor, 1, wx.EXPAND)
            sizer.Add(SearchPanel(self), 0, wx.EXPAND)
            self.SetSizer(sizer)
            self.SetSize((400, 400))

    app = wx.PySimpleApp()
    win = TestFrame()
    win.Show(True)
    app.MainLoop()
